@@ -5,6 +5,9 @@ from shutil import rmtree
 
 # http://stackoverflow.com/questions/600268/mkdir-p-functionality-in-python
 def mkdir_recursive(path):
+    """
+    Creates directories recursively
+    """
     try:
         os.makedirs(path)
     except OSError as exc:  # Python >2.5
@@ -15,4 +18,7 @@ def mkdir_recursive(path):
 
 
 def rmdir(path):
+    """
+    Removes directories and files
+    """
     rmtree(path)
